<?php


namespace App\Modules\OrangeSite\Services\CheckReport;


use App\Modules\Callback\Services\CallbackBaseService;
use App\Modules\OrangeSite\Services\OrangeSiteRechargeReportCheckContext;
use Closure;
use Log;

class ReportRechargeTypeCheck
{
    /**
     * 判断订单,是不是满足如下回传类型之一:
     * 回传当天自然日注册且首次充值的用户
     * 回传24小时注册且首次充值的用户
     * @param $context OrangeSiteRechargeReportCheckContext
     * @param Closure $next
     * @return mixed
     */
    public function handle($context, Closure $next)
    {
        $typeMap = [
            'no_current_day_register' => '非充值当天注册用户',
            'no_register_24_charge' => '非充值24小时内注册用户'
        ];
        $reportType = $context->channelCallbackConfig->callback_type;
        $result = CallbackBaseService::callbackType($reportType, $context->user->created_at);
        if (is_array($result) && array_key_exists('result', $result) && (false == $result['result'])) {
            Log::debug('[orangeSiteRechargeReport]用户注册时间不满足回传类型配置',
                ['traceInfo' => $context->traceContext->getTraceInfo()]);
            $result['content'] = $typeMap[$result['type']] ?? '';
            $context->result = $result;
            $context->result['firstReason'] = 'ReportRechargeTypeCheck';
            $context->result['type'] = trim($result['type'], 'no_');
            return $context;
        }

        if ($context->order->pay_type != 1) {
            Log::debug('[orangeSiteRechargeReport]当前订单非用户首充',
                ['traceInfo' => $context->traceContext->getTraceInfo()]);
            $context->result = [
                'result' => false,
                'type' => 'feedback_user',
                'firstReason' => 'ReportRechargeTypeCheck',
                'content' => '用户非首充',
            ];
            return $context;
        }

        return $next($context);
    }
}