<?php

namespace App\Service\WechatPlatform;

use App\Service\Util\Support\Http\HttpRequestService;
use App\Service\Util\Support\Http\WechatURL;
use EasyWeChat\OpenPlatform\Application;
use Illuminate\Support\Facades\Cache;

class GZHSendKFMessageService
{
    /**
     * 发送文本客服消息
     * @param $officialAccount \EasyWeChat\OfficialAccount\Application
     * @param $openid
     * @param $content
     * @param $traceContext
     * @return bool
     */
    public static function sendText($officialAccount, $openid, $content, $traceContext) {
        try {
            $res = $officialAccount->customer_service->message($content)
                ->to($openid)->send();
            myLog('KFMessageSend')->debug('客服消息发送结果:', [
                'res' => $res,
                'traceInfo' => $traceContext->getTraceInfo()
            ]);
            return true;
        } catch (\Throwable $exception) {
            myLog('KFMessageSend')->error('发送客服消息失败', [
                'openid' => $openid, 'content' => $content,
                'exceptionMsg' => $exception->getMessage(),
                'expTrace' => $exception->getTraceAsString(),
                'traceInfo' => $traceContext->getTraceInfo()
            ]);
            return false;
        }
    }


}
